@@ -6,13 +6,12 @@
 
     <td valign="top">
 
-      <p class="block"><i>ttyrpld</i> is a Kernel-based keylogger and
-      screenlogger for Linux, FreeBSD and OpenBSD, and includes a real-time,
-      tail-following log analyzer. It supports most tty types, including
-      <tt>vc</tt>, bsd and unix98-style <tt>pty</tt>s (xterm/ssh), serial,
-      isdn, etc. Being implemented within the Kernel makes it unavoidable for
-      the default user. Another benefit is that it runs with no overhead if the
-      user-space logging daemon is not active.</p>
+      <p class="block"><i>ttyrpld</i> is a mult-os kernel-level tty key- and
+      screenlogger with (a)synchronous replay supprt. It supports most tty
+      types, including <tt>vc</tt>, bsd and unix98-style <tt>pty</tt>s
+      (xterm/ssh), serial, isdn, etc. Being implemented within the Kernel makes
+      it unavoidable for the default user. It runs with no overhead if the
+      logging daemon is not active.</p>
 
     </td>
   </tr>
@@ -26,12 +25,6 @@
 
     <td valign="top">
       <div class="indent"><table border="1" class="sBorder">
-        <tr>
-          <td>Super Short Description:</td>
-          <td>Incircumventable Kernel-based tty keylogger and screenlogger for
-            Linux/FreeBSD/OpenBSD with real-time and tail-follow log analyzer.
-            Supports vc, bsd/unix98 pty (xterm/ssh), serial, isdn, etc.</td>
-        </tr>
         <tr>
           <td>Development Status:</td>
           <td>6 - Mature</td>
@@ -43,18 +36,22 @@
         </tr>
         <tr>
           <td>License:</td>
-          <td>GNU General Public License (GPL) version 2</td>
+          <td><ul>
+              <li>GNU Lesser General Public License (LGPL) version 2.1</li>
+              <li>BSD-style (for BSD parts)</li>
+            </ul></td>
         </tr>
         <tr>
           <td>Languages (natural first):</td>
-          <td>English, Persian-Farsi (<tt>ar_IQ</tt>), German (<tt>de</tt>),
+          <td>English, Persian-Farsi (<tt>fa_IR</tt>), German (<tt>de</tt>),
             Spanish (<tt>es</tt>), French (<tt>fr</tt>), Italian (<tt>it</tt>),
             Norwegian-Bokmål (<tt>nb</tt>), Netherlandish (<tt>nl</tt>),
             Swedish (<tt>sv</tt>)</td>
         </tr>
         <tr>
           <td>Operating Systems:</td>
-          <td>Linux 2.4/2.6, FreeBSD 6.0, OpenBSD 3.8</td>
+          <td>Linux 2.4/2.6, FreeBSD 5.3/6.0, OpenBSD 3.8, NetBSD 3.0<br />
+            (and possibly offsprings)</td>
         </tr>
         <tr>
           <td>Programming Language:</td>
@@ -66,7 +63,7 @@
         </tr>
         <tr>
           <td>Environment:</td>
-          <td>Non-interactive (Daemon), Command-line, Console/Terminal</td>
+          <td>Non-interactive (Daemon), Console/Terminal</td>
         </tr>
       </table></div>
     </td>
@@ -87,12 +84,11 @@
       userspace and make it dependent on the user to activate the logging. 
       Definitely, an intruder does not start e.g. <tt>/usr/bin/script</tt>
       voluntarily. I have only seen few other kernel-based loggers. One of them
-      is sadly outdated, others query the X86 keyboard driver using interrupt
-      hijacking and table translation. This is very unportable, because it only
-      catches AT keyboards, but not USB or even other keyboards (unless they
-      are in compatibility mode), and it does not work at all for network
-      traffic. To sum it up, there exist only very few solutions to which I
-      could compare.</p>
+      is outdated, others query the X86 keyboard driver using interrupt
+      hijacking and fixed translation. This is very unportable, because it only
+      catches raw AT keyboard scancodes, but not USB or even other keyboards
+      (unless they are in compatibility mode), and it does not work at all for
+      network traffic.</p>
 
       <p class="block">Only the FreeBSD snooper <i>watch</i>, which operates on
       the <tt>/dev/snp*</tt> devices, can be taken for a comparison. However,
@@ -116,8 +112,7 @@
 
       <p class="block"><i>kpatch</i>: The Kernel patch adds a few lines to
       provide the <i>rpldev</i> extension hooks, which (any) module can then
-      get onto. The system was not directly written for black-hats who want to
-      leave as little traces as possible, keep in mind. <tt>:-)</tt></p>
+      get onto.</p>
 
       <p class="block"><i>rpldev</i>: The Kernel module is responsible for
       grabbing the data off the tty line and providing a character device for
@@ -125,9 +120,9 @@
       to the overlying daemons, so with the correct terminal settings you can
       get a 1:1 replay.</p>
 
-      <p class="block">For systems where module loading is not possible
-      (OpenBSD for example), these two components are integrated into the
-      kpatch.</p>
+      <p class="block">For systems where module loading is not possible or not
+      widely supported (OpenBSD for example), <i>rpldev</i> is integrated into
+      the kpatch.</p>
 
       <p class="block"><i>rpld</i>: Having received the captured data, the
       logging daemon can store them in any format and/or facility, with or
@@ -135,8 +130,8 @@
       thus you have all the fluffy libraries available. (That would not be the
       case from Kernel space.)</p>
 
-      <p class="block"><i>ttyreplay</i>: real-time log analyzer. Think of it
-      like <a href="http://mplayerhq.hu/" target="_blank">mplayer</a>.</p>
+      <p class="block"><i>ttyreplay</i>: real-time log analyzer. Think of it as
+      a simple video player.</p>
 
     </td>
   </tr>
