@@ -1,4 +1,68 @@
 <?php include_once("_header.php"); ?>
+  <tr>
+    <td align="right" valign="top"
+      class="section"><b>Requirements&nbsp;&gt;</b></td>
+    <td valign="top">
+
+      <table border="1" class="sBorder">
+        <tr>
+          <td><i>Component</i></td>
+          <td><i>Minimum</i></td>
+          <td><i>Recommended</i>, or better</td>
+        </tr>
+        <tr>
+          <td>GNU make</td>
+          <td>3.79</td>
+          <td>3.80</td>
+        </tr>
+        <tr>
+          <td>BSD make<br />
+            (only applies to *BSD targets)</td>
+          <td colspan="2"><i>as shipped with your distribution</i></td>
+        </tr>
+        <tr>
+          <td><a href="http://jengelh.hopto.org/coding/libHX.php">libHX</a></td>
+          <td>1.8.0</li>
+          <td>1.8.0</li>
+        </tr>
+        <tr>
+          <td>GNU C Compiler</td>
+          <td>3.3</li>
+          <td>4.x</li>
+        </tr>
+        <tr>
+          <td colspan="3"><i>Auxiliary tools (i.e. unpacking, documentation,
+            etc.&nbsp;-- not strictly needed on the compiling machine)</i></td>
+        </tr>
+        <tr>
+          <td>perl</td>
+          <td>5.6.0</td>
+          <td>&gt;= 5.6.0</td>
+        </tr>
+        <tr>
+          <td>php</td>
+          <td>4.x</td>
+          <td>&gt;= 4.x</td>
+        </tr>
+        <tr>
+          <td>w3m</td>
+          <td>0.5.0</td>
+          <td>0.5.1</td>
+        </tr>
+        <tr>
+          <td>bzip2, patch, tar</td>
+          <td colspan="2"><i>whatever works</i></td>
+        </tr>
+        <tr>
+          <td colspan="3"><i>Please check your kernel documentation on what
+            more tools are needed for a kernel compilation.</i></td>
+        </tr>
+      </table>
+    </td>
+  </tr>
+  <tr>
+    <td>&nbsp;</td>
+  </tr>
   <tr>
     <td align="right" valign="top"
       class="section"><b>Unpacking&nbsp;&gt;</b></td>
@@ -104,7 +168,7 @@
   </tr>
   <tr>
     <td align="right" valign="top" class="section"><b>Patching the Kernel
-      sources (OpenBSD)&nbsp;&gt;</b></td>
+      sources (OpenBSD and NetBSD)&nbsp;&gt;</b></td>
     <td valign="top">
 
       <p class="block">The process is not much different:</p>
@@ -131,6 +195,7 @@
       </div>
 
     </td>
+  </tr>
   <tr>
     <td>&nbsp;</td>
   </tr>
@@ -182,19 +247,9 @@
 
       <p class="block">To compile the user-space tools, run `<tt>make</tt>`
       (BSD: `<tt>gmake</tt>`) without any arguments. This will build
-      <tt>rpld</tt> and <tt>ttyreplay</tt> (the daemon and the log
-      analyzer). If you want to build HTML documentation from the PHP files,
-      you need to use `<tt>gmake doc</tt>`.</p>
-
-      <p class="block">You will need <i><a
-      href="http://jengelh.hopto.org/coding/libHX.php"
-      target="_blank">libHX</a></i> to use <i>ttyrpld</i> since it makes use of
-      advanced data storage and string functions not present in libc.</p>
-
-      <p class="block">It is recommended that you use <i>gcc version 3 or
-      version 4</i>. However, <i>gcc2</i> can also be used with minor
-      modifications to the dependency file generation instructions in the
-      Makefiles.</p>
+      <tt>rpld</tt> and <tt>ttyreplay</tt> (the daemon and the log analyzer).
+      If you want to build HTML and TXT documentation from the PHP files, you
+      need to use `<tt>gmake doc</tt>`.</p>
 
     </td>
   </tr>
