@@ -15,7 +15,7 @@
 
       <p class="block">The logfiles <i>rpld</i> creates are a small variation
       of the packet protocol as described in <a
-      href="man_rpldev.4.php">rpldev(4)</a>. The <tt>.dev</tt> and field is not
+      href="man_rpldev.4.php">rpldev(4)</a>. The <tt>.dev</tt> field is not
       present. (Since ttyrpld v2.00, the timestamp is already added in the
       kernel.) All fields are little endian and packed, i.e. there are no
       alignment gaps. The structure is similar to the <tt>struct
@@ -37,18 +37,21 @@
       <div class="indent">
         <p class="code"><tt>
         <b>enum</b> {<br />
-        &nbsp; &nbsp; EVT_ID_PROG = 0xF0,<br />
-        &nbsp; &nbsp; EVT_ID_DEVPATH = 0xF1,<br />
-        &nbsp; &nbsp; EVT_ID_TIME = 0xF2,<br />
-        &nbsp; &nbsp; EVT_ID_USER = 0xF3,<br />
+        &nbsp; &nbsp; EVT_MAGIC <b>=</b> 0x4A,<br />
+        &nbsp; &nbsp; EVT_ID_PROG <b>=</b> 0xF0,<br />
+        &nbsp; &nbsp; EVT_ID_DEVPATH <b>=</b> 0xF1,<br />
+        &nbsp; &nbsp; EVT_ID_TIME <b>=</b> 0xF2,<br />
+        &nbsp; &nbsp; EVT_ID_USER <b>=</b> 0xF3,<br />
         };</tt></p>
       </div>
 
-      <p class="block"><tt>EVT_ID_PROG</tt> is added by <i>rpld</i> to contain
-      the program with which it was created.</p>
+      <p class="block">A <tt>EVT_ID_PROG</tt> is added to each logfile by
+      <i>rpld</i> to contain the program with which it was created.
+      (<i>rpld</i> in this case&nbsp;-- but anyone is free to write a different
+      daemon.)</p>
 
-      <p class="block"><tt>EVT_ID_DEVPATH</tt> contains the path of the device
-      node that has been tapped. There is a special handling case in
+      <p class="block">A <tt>EVT_ID_DEVPATH</tt> contains the path of the
+      device node that has been tapped. There is a special handling case in
       <i>rpld</i> when multiple device nodes with the same major-minor number
       are used at the same time:</p>
 
