@@ -37,10 +37,10 @@
       flexible.</p>
 
       <p class="block">Seven variable function pointers&nbsp;--
-      <tt>rpl_qinit</tt>, <tt>rpl_qopen</tt>, <tt>rpl_qread</tt>,
-      <tt>rpl_qwrite</tt>, <tt>rpl_qclose</tt>, <tt>rpl_qdeinit</tt> and
-      <tt>rpl_qioctl</tt>&nbsp;-- are exported from <tt>tty_io.c</tt> for
-      module hook-up. That means that a module has to redirect them to its own
+      <tt>rpl_init</tt>, <tt>rpl_open</tt>, <tt>rpl_read</tt>,
+      <tt>rpl_write</tt>, <tt>rpl_close</tt>, <tt>rpl_deinit</tt> and
+      <tt>rpl_ioctl</tt>&nbsp;-- are exported from <tt>tty_io.c</tt> for module
+      hook-up. That means that a module has to redirect them to its own
       functions, when it shall go into action. That way, there is no overhead
       (read: (usually) 2 CPU instructions) when rpldev logging is not
       active.</p>
@@ -48,21 +48,21 @@
       <div class="indent">
         <p class="block"><i>Excerpt from <tt>drivers/char/tty_io.c</tt></i></p>
         <p class="code"><tt>
-        <b>#</b>ifdef CONFIG_TTY_RPL<br />
-        <b>#</b> &nbsp; &nbsp;include &lt;linux/rpl.h&gt;<br />
-        <b>int (*</b>rpl_qinit<b>)</b>(<b>struct</b> tty_struct <b>*</b>, <b>struct</b> tty_struct <b>*</b>);<br />
-        <b>int (*</b>rpl_qopen<b>)</b>(<b>struct</b> tty_struct <b>*</b>, <b>struct</b> tty_struct <b>*</b>);<br />
-        <b>int (*</b>rpl_qread<b>)</b>(<b>const char __user *</b>, <b>size_t</b>, <b>struct</b> tty_struct <b>*</b>);<br />
-        <b>int (*</b>rpl_qwrite<b>)</b>(<b>const char __user *</b>, <b>size_t</b>, <b>struct</b> tty_struct <b>*</b>);<br />
-        <b>int (*</b>rpl_qclose<b>)</b>(<b>struct</b> tty_struct <b>*</b>, <b>struct</b> tty_struct <b>*</b>);<br />
-        <b>int (*</b>rpl_qdeinit<b>)</b>(<b>struct</b> tty_struct <b>*</b>, <b>struct</b> tty_struct <b>*</b>);<br />
-        <b>int (*</b>rpl_qioctl<b>)</b>(<b>struct</b> tty_struct <b>*</b>, <b>struct</b> tty_struct <b>*</b>, <b>unsigned int</b>, <b>unsigned long</b>);<br />
+        <b>#</b>ifdef CONFIG_RPLDHK<br />
+        <b>#</b> &nbsp; &nbsp;include &lt;linux/km_rpldev.h&gt;<br />
+        <b>int (*</b>rpl_init<b>)</b>(<b>struct</b> tty_struct <b>*</b>, <b>struct</b> tty_struct <b>*</b>);<br />
+        <b>int (*</b>rpl_open<b>)</b>(<b>struct</b> tty_struct <b>*</b>, <b>struct</b> tty_struct <b>*</b>);<br />
+        <b>int (*</b>rpl_read<b>)</b>(<b>const char __user *</b>, <b>size_t</b>, <b>struct</b> tty_struct <b>*</b>);<br />
+        <b>int (*</b>rpl_write<b>)</b>(<b>const char __user *</b>, <b>size_t</b>, <b>struct</b> tty_struct <b>*</b>);<br />
+        <b>int (*</b>rpl_close<b>)</b>(<b>struct</b> tty_struct <b>*</b>, <b>struct</b> tty_struct <b>*</b>);<br />
+        <b>int (*</b>rpl_deinit<b>)</b>(<b>struct</b> tty_struct <b>*</b>, <b>struct</b> tty_struct <b>*</b>);<br />
+        <b>int (*</b>rpl_ioctl<b>)</b>(<b>struct</b> tty_struct <b>*</b>, <b>struct</b> tty_struct <b>*</b>, <b>unsigned int</b>, <b>unsigned long</b>);<br />
         <b>#</b>endif</tt></p>
 
         <p class="code"><tt>
-        <b>#</b>ifdef CONFIG_TTY_RPL<br />
-        <b>if</b>(rpl_qwrite <b>!=</b> NULL)<br />
-        &nbsp; &nbsp; rpl_qwrite(buf, i, tty);<br />
+        <b>#</b>ifdef CONFIG_RPLDHK<br />
+        <b>if</b>(rpl_write <b>!=</b> NULL)<br />
+        &nbsp; &nbsp; rpl_write(buf, i, tty);<br />
         <b>#</b>endif</tt></p>
       </div>
 
@@ -92,7 +92,7 @@
       <p class="block">The 2nd stage consists of the functions behind the
       <tt>rpl_*</tt> variables, the functions as present in the module. They
       copy the data "captured" (let's say it was passed voluntarily) by the tty
-      driver to a buffer, so that <tt>rpl_qopen()</tt> can return as soon as
+      driver to a buffer, so that <tt>rpl_open()</tt> can return as soon as
       possible to not block the tty driver.</p>
 
       <p class="block">This can get a little problematic if you have a lot of
@@ -106,21 +106,21 @@
       href="man_rpldev.4.php">rpldev(4)</a> for details on the protocol.</p>
 
       <div class="indent">
-        <p class="block"><i>Excerpt from <tt>kernel-2.6/rpldev.c</tt></i></p>
+        <p class="block"><i>Excerpt from <tt>k_linux-2.6/rpldev.c</tt></i></p>
 
         <p class="code"><tt>
         <b>static int</b> krpl_write(<b>const char</b> __user <b>*</b>buf, <b>size_t</b> count, <b>struct</b> tty_struct <b>*</b>tty)&nbsp;{<br />
         &nbsp; &nbsp; <b>struct</b> rpld_packet p;<br />
         <br />
         &nbsp; &nbsp; SKIP_PTM(tty);<br />
-        &nbsp; &nbsp; if(count == 0) { return 0; }<br />
+        &nbsp; &nbsp; if(count == 0) return 0;<br />
         <br />
         &nbsp; &nbsp; p.dev &nbsp; = TTY_DEVNR(tty);<br />
         &nbsp; &nbsp; p.size &nbsp;= cpu_to_le16(count);<br />
         &nbsp; &nbsp; p.event = EVT_READ;<br />
         &nbsp; &nbsp; p.magic = MAGIC_SIG;<br />
         &nbsp; &nbsp; fill_time(&p.time);<br />
-        &nbsp; &nbsp; <b>return</b> mv_buffer(&amp;p, buf, count);<br />
+        &nbsp; &nbsp; <b>return</b> circular_put_packet(&amp;p, buf, count);<br />
         }</tt></p>
       </div>
 
