@@ -1,25 +1,25 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/replay.c - Realtime TTY log analyzer
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2006
-  -- License restrictions apply (GPL v2)
+  Copyright © Jan Engelhardt <jengelh [at] gmx de>, 2004 - 2006
+  -- License restrictions apply (LGPL v2.1)
 
   This file is part of ttyrpld.
   ttyrpld is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; however ONLY version 2 of the License.
+  under the terms of the GNU Lesser General Public License as published
+  by the Free Software Foundation; however ONLY version 2 of the License.
 
   ttyrpld is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details.
+  Lesser General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program kit; if not, write to:
+  You should have received a copy of the GNU Lesser General Public
+  License along with this program kit; if not, write to:
   Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
   Boston, MA  02110-1301  USA
 
-  -- For details, see the file named "LICENSE.GPL2"
+  -- For details, see the file named "LICENSE.LGPL2"
 =============================================================================*/
 #include <sys/stat.h>
 #include <sys/time.h> // usec def, gettimeofday()
@@ -160,7 +160,7 @@ static int replay_file(int fd, const char *name) {
     struct rpldsk_packet packet;
     struct pctrl_info ps;
     struct timeval stamp;
-    ssize_t eax;
+    ssize_t ret;
     long skew = 0;
     char tick = 0;
 
@@ -174,8 +174,9 @@ static int replay_file(int fd, const char *name) {
     ps.skval  = Opt.skval;
     pctrl_activate(&ps);
 
-    while((eax = read_waitfm(fd, &packet,
-     sizeof(struct rpldsk_packet), &ps)) == sizeof(struct rpldsk_packet)) {
+    while((ret = read_waitfm(fd, &packet,
+     sizeof(struct rpldsk_packet), &ps)) == sizeof(struct rpldsk_packet))
+    {
         if(packet.magic != MAGIC_SIG) {
             fprintf(stderr, _("\n" "<Packet inconsistency! "
              "Trying to find next valid packet.>\n"));
@@ -239,7 +240,7 @@ static int replay_file(int fd, const char *name) {
 
     pctrl_deactivate(0);
 
-    if(eax < 0)
+    if(ret < 0)
         fprintf(stderr, "\n\e[1;37;41m%s\e[0m\nread(): %s\n", // ]]
          _("<Error while reading from stream>"), strerror(errno));
 
@@ -305,10 +306,10 @@ static void e_proc(int fd, struct rpldsk_packet *p, struct pctrl_info *i,
         localtime_r(&now, &tm);
 
         if(Opt.showtime == 1)
-            strftime(buf, sizeof(buf), "\e7\e[1;300H\e[9D" // ]]
+            strftime(buf, sizeof(buf), "\e7\e[1;300H\e[10D" // ]]
              "\e[0;7m[\e[0;1;37;41m" "%H:%M:%S" "\e[0;7m]\e8\e[0m", &tm); // ]]]]
         else
-            strftime(buf, sizeof(buf), "\e7\e[1;300H\e[12D" // ]]
+            strftime(buf, sizeof(buf), "\e7\e[1;300H\e[13D" // ]]
              "\e[0;7m[\e[0;1;37;41m" "%d.%m %H:%M" "\e[0;7m]\e8\e[0m", &tm); // ]]]]
 
         write(STDOUT_FILENO, buf, strlen(buf));
@@ -510,13 +511,13 @@ static ssize_t read_through(int in, int out, size_t count) {
     size_t rem = count;
 
     while(rem > 0) {
-        ssize_t eax = read(in, buf, min_uint(BUFSIZE, rem));
-        if(eax < 0)
+        ssize_t ret = read(in, buf, min_uint(BUFSIZE, rem));
+        if(ret < 0)
             return 0;
-        write(out, buf, eax);
-        if(eax == rem)
+        write(out, buf, ret);
+        if(ret == rem)
             break;
-        rem -= eax;
+        rem -= ret;
         usleep(10000);
     }
 
