@@ -1,29 +1,28 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/rpld.c - User space daemon (filtering, etc.)
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2006
+  Copyright © Jan Engelhardt <jengelh [at] gmx de>, 2004 - 2006
   Copyright © Nguyen Anh Quynh <aquynh [at] gmail com>, 2005
-  -- License restrictions apply (GPL v2)
+  -- License restrictions apply (LGPL v2.1)
 
   This file is part of ttyrpld.
   ttyrpld is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; however ONLY version 2 of the License.
+  under the terms of the GNU Lesser General Public License as published
+  by the Free Software Foundation; however ONLY version 2 of the License.
 
   ttyrpld is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details.
+  Lesser General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program kit; if not, write to:
+  You should have received a copy of the GNU Lesser General Public
+  License along with this program kit; if not, write to:
   Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
   Boston, MA  02110-1301  USA
 
-  -- For details, see the file named "LICENSE.GPL2"
+  -- For details, see the file named "LICENSE.LGPL2"
 =============================================================================*/
 #include <sys/types.h>
-#include <sys/mman.h> // mlock()
 #include <sys/stat.h>
 #include <sys/time.h> // gettimeofday()
 #include <ctype.h>
@@ -70,8 +69,6 @@ static int check_parent_directory(const char *);
 static void fill_info(struct tty *, const char *);
 
 static int init_device(const char *);
-static int init_sbuffer(int);
-static void deinit_sbuffer(void);
 static int init_sighandler(void);
 static void sighandler_int(int);
 static void sighandler_alrm(int);
@@ -89,7 +86,6 @@ static int read_config(const char *);
 static int read_config_bp(const char *, const char *);
 
 // Global variables (begin with uppercase character)
-static void *Buffer = NULL;
 static struct {
     int _running, dolog;
     char *device;
@@ -109,7 +105,7 @@ int main(int argc, const char **argv) {
     int fd;
 
     load_locale(*argv);
-    umask(~(S_IWUSR | S_IXUSR));
+    umask(~(S_IRUSR | S_IWUSR | S_IXUSR));
 
     /* Yep, the config file is what is needed by all three
     (rpld, infod, rplctl). */
@@ -150,9 +146,7 @@ int main(int argc, const char **argv) {
         return EXIT_FAILURE;
     }
 
-    if(init_sbuffer(fd) < 0) return EXIT_FAILURE;
     init_sighandler();
-
     if(Opt.infod_start)  infod_init();
     if(GOpt.syslog)      openlog("rpld", LOG_PID, LOG_DAEMON);
     if(GOpt.user_id > 0) setuid(GOpt.user_id);
@@ -167,7 +161,6 @@ int main(int argc, const char **argv) {
     }
 
     close(fd);
-    deinit_sbuffer();
     return EXIT_SUCCESS;
 }
 
@@ -175,21 +168,21 @@ static void mainloop(int fd) {
     while(Opt._running) {
         struct rpldev_packet packet;
         struct tty *tty;
-        ssize_t eax;
+        ssize_t ret;
 
-        if((eax = read(fd, &packet, sizeof(struct rpldev_packet))) <
+        if((ret = read(fd, &packet, sizeof(struct rpldev_packet))) <
          (ssize_t)sizeof(struct rpldev_packet)) {
             struct stat sb;
-#ifdef __OpenBSD__
+#if defined(__OpenBSD__) || defined(__NetBSD__)
             int e = errno;
 #endif
             fstat(fd, &sb);
             if(!S_ISREG(sb.st_mode)) {
-#ifdef __OpenBSD__
+#if defined(__OpenBSD__) || defined(__NetBSD__)
                 if(e == EINTR) continue;
 #endif
                 fprintf(stderr, _("\n" "Short read: %ld bytes only. "
-                 "Error %d: %s\n"), (long)eax, errno, strerror(errno));
+                 "Error %d: %s\n"), (long)ret, errno, strerror(errno));
             }
             Opt._running = 0;
             break;
@@ -369,35 +362,41 @@ static void log_open(struct tty *tty) {
     if(tty->fd >= 0)
         close(tty->fd);
 
-    tty->fd = open(tty->log, O_WRONLY | O_CREAT | O_APPEND, S_IWUSR);
+    tty->fd = open(tty->log, O_WRONLY | O_CREAT | O_APPEND, S_IRUSR | S_IWUSR);
+
+    /* Add an optional magic packet for file(1) to recognize. (EVT_ID_PROG may
+    contain _anything_, while EVT_MAGIC is fixed. See share/ttyrpld.magic.) */
+    strncpy(buf, "RPL", sizeof(buf) - 1); // <-- STRING FIXED
+    buf[sizeof(buf)-1] = '\0';
+    p.event = EVT_MAGIC;
+    s = p.size = strlen(buf) + 1; // include '\0' in stream
+    SWAB1(&p.size);
+    write(tty->fd, &p, sizeof(struct rpldsk_packet));
+    write(tty->fd, buf, s);
 
     /* Add an optional ident header to record the program and version which
     this logfile was created with. */
     strncpy(buf, "ttyrpld " TTYRPLD_VERSION, sizeof(buf) - 1);
     buf[sizeof(buf) - 1] = '\0';
     p.event = EVT_ID_PROG;
-    s = p.size = strlen(buf);
+    s = p.size = strlen(buf) + 1;
     SWAB1(&p.size);
     write(tty->fd, &p, sizeof(struct rpldsk_packet));
     write(tty->fd, buf, s);
 
     // Also add the timestamp this log was created
     now_sec = time(NULL);
-#if defined(__OpenBSD__)
-    nowp = localtime(&now_sec);
-#else
     nowp = localtime_r(&now_sec, &now_tm);
-#endif
     strftime(buf, sizeof(buf), "%Y-%m-%d %H:%M:%S", nowp);
     p.event = EVT_ID_TIME;
-    s = p.size = strlen(buf);
+    s = p.size = strlen(buf) + 1;
     SWAB1(&p.size);
     write(tty->fd, &p, sizeof(struct rpldsk_packet));
     write(tty->fd, buf, s);
 
     // ... and the full path name of the tty for reference.
     p.event = EVT_ID_DEVPATH;
-    s = p.size = strlen(tty->full_dev);
+    s = p.size = strlen(tty->full_dev) + 1;
     SWAB1(&p.size);
     write(tty->fd, &p, sizeof(struct rpldsk_packet));
     write(tty->fd, tty->full_dev, s);
@@ -406,7 +405,7 @@ static void log_open(struct tty *tty) {
     if(getnamefromuid(tty->uid, buf, sizeof(buf)) == NULL)
         snprintf(buf, sizeof(buf), "%ld", (long)tty->uid);
     p.event = EVT_ID_USER;
-    s = p.size = strlen(buf);
+    s = p.size = strlen(buf) + 1;
     SWAB1(&p.size);
     write(tty->fd, &p, sizeof(struct rpldsk_packet));
     write(tty->fd, buf, s);
@@ -567,35 +566,6 @@ static int init_device(const char *in_devs) {
     return fd;
 }
 
-static int init_sbuffer(int fd) {
-    int eax = -1;
-
-    if(D_IOCTL(fd, RPL_IOC_GETBUFSIZE, &eax) && eax > 0)
-        Opt.bsize = eax;
-
-#if defined(__FreeBSD__) || defined(__OpenBSD__)
-    if((Buffer = malloc(Opt.bsize)) == NULL)
-#else
-    if(posix_memalign(&Buffer, sysconf(_SC_PAGESIZE), Opt.bsize) != 0)
-#endif
-    {
-        eax = errno;
-        perror("malloc()/posix_memalign()");
-        return -(errno = eax);
-    }
-
-    /* Done so that this memory area can not be swapped out, which is essential
-    against buffer overruns. */
-    mlock(Buffer, Opt.bsize);
-    return 1;
-}
-
-static void deinit_sbuffer(void) {
-    munlock(Buffer, Opt.bsize);
-    free(Buffer);
-    return;
-}
-
 static int init_sighandler(void) {
     struct sigaction s_int, s_alrm, s_pipe;
 
